From: Geert Uytterhoeven <geert@linux-m68k.org>

BVME6000 SCSI: Fix typos



---

 25-akpm/drivers/scsi/bvme6000.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff -puN drivers/scsi/bvme6000.c~68k-366 drivers/scsi/bvme6000.c
--- 25/drivers/scsi/bvme6000.c~68k-366	Thu Jan  8 15:37:36 2004
+++ 25-akpm/drivers/scsi/bvme6000.c	Thu Jan  8 15:37:36 2004
@@ -1,5 +1,5 @@
 /*
  * Detection routine for the NCR53c710 based MVME16x SCSI Controllers for Linux.
  *
  * Based on work by Alan Hourihane
  */
@@ -48,7 +48,7 @@ int bvme6000_scsi_detect(Scsi_Host_Templ
     return 1;
 }
 
-static int mvme6000_scsi_release(struct Scsi_Host *shost)
+static int bvme6000_scsi_release(struct Scsi_Host *shost)
 {
 	if (shost->irq)
 		free_irq(shost->irq, NULL);
@@ -1,5 +1,5 @@
 /*
- * Detection routine for the NCR53c710 based MVME16x SCSI Controllers for Linux.
+ * Detection routine for the NCR53c710 based BVME6000 SCSI Controllers for Linux.
  *
  * Based on work by Alan Hourihane

_